﻿// License: The MIT License (MIT) Copyright (c) 2011..2012 Barend Gehrels

// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Linq;

namespace GrooveSharp
{
    public static class SettingManager
    {
        const int KEY_ANNOUNCE = 1;
        private static IList<Setting> m_currentSettings = null;

        private static void Initialize()
        {
            if (m_currentSettings == null)
            {
                m_currentSettings = Db.Connection().Select<Setting>("select * from settings").ToList();
            }
        }

        private static bool UseKey(int key)
        {
            Initialize();
            // Strangely enough FirstOrDefault gives a nullpointer exception (?).
            // Anyway, we then loop through it.
            foreach (var it in (from item in m_currentSettings where item.SettingKey == key select item))
            {
                return it.Active;
            }
            return false;
        }

        public static bool UseAnnouncer()
        {
            return UseKey(KEY_ANNOUNCE);
        }

        public static void Reset()
        {
            m_currentSettings = null;
        }

        private static void InsertOrUpdate(int setting, bool? value)
        {
            if (value.HasValue)
            {
                int intValue = value.Value ? 1 : 0;
                string condition =  String.Format(" where setting_key={0}", setting);
                int count = Db.SelectFirstOrDefault<int>("select count(1) from settings" + condition, 0);
                if (count == 0)
                {
                    Db.Connection().Execute(String.Format("insert into settings(setting_key,setting_value) values({0},{1})", setting, intValue));
                }
                else
                {
                    Db.Connection().Execute(String.Format("update settings set setting_value={0}", intValue) + condition);
                }
            }
        }

        public static void InsertOrUpdate(bool? checkAnnounce)
        {
            InsertOrUpdate(KEY_ANNOUNCE, checkAnnounce);
        }
    }
}
