﻿// License: The MIT License (MIT) Copyright (c) 2011..2012 Barend Gehrels

// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Data;
using Stormy;

namespace GrooveSharp
{
    public class AlbumMapper : ISelectable<Album>, IInsertable<Album>, IAutoNumberable<Album>
    {
        public Album ApplySelect(IDataReader reader)
        {
            Album album = new Album();
            album.Id = reader.AsInteger("album_id").Value;
            album.Title = reader.AsString("album_title");
            return album;
        }

        public void ApplyInsert(Album album, IDbCommand command)
        {
            command.Parameters.Add(Db.CreateParameter(command, DbType.String, "@title", album.Title));
            command.Parameters.Add(Db.CreateParameter(command, DbType.String, "@sorttitle", album.SortTitle));
        }

        public void ApplyAutoNumber(Album album, int newId)
        {
            album.Id = newId;
        }

        public string InsertSql()
        {
            return "insert into albums(album_title, album_sorttitle) values(@title, @sorttitle)";
        }
    }
}
