﻿// License: The MIT License (MIT) Copyright (c) 2011..2012 Barend Gehrels

// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Data;
using Stormy;

namespace GrooveSharp
{

    public class GenreMapper : ISelectable<Genre>, IInsertable<Genre>, IAutoNumberable<Genre>
    {
        public Genre ApplySelect(IDataReader reader)
        {
            Genre genre = new Genre();
            genre.Id = reader.AsInteger("genre_id").Value;
            genre.Name = reader.AsString("genre_name");
            return genre;
        }

        public void ApplyInsert(Genre genre, IDbCommand command)
        {
            command.Parameters.Add(Db.CreateParameter(command, DbType.String, "@name", genre.Name));
        }

        public void ApplyAutoNumber(Genre genre, int newId)
        {
            genre.Id = newId;
        }

        public string InsertSql()
        {
            return "insert into genres(genre_name) values(@name)";
        }
    }

}
