﻿// License: The MIT License (MIT) Copyright (c) 2011..2012 Barend Gehrels

// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Data;
using Stormy;

namespace GrooveSharp
{
    public class PlayMapper : ISelectable<Play>, IInsertable<Play>, IUpdateable<Play>, IAutoNumberable<Play>
    {
        public Play ApplySelect(IDataReader reader)
        {
            Play Play = new Play();
            try
            {
                Play.Id = reader.AsInteger("play_id").Value;
                Play.TrackId = reader.AsInteger("track_id").Value;
                Play.PlayDate = reader.AsDate("play_date");
                Play.Span = reader.AsTimeSpan("play_duration");
            }
            catch { }

            return Play;
        }

        public void ApplyInsert(Play play, IDbCommand command)
        {
            command.Parameters.Add(Db.CreateParameter(command, DbType.Int32, "@trackid", play.TrackId));
            command.Parameters.Add(Db.CreateParameter(command, DbType.Int32, "@userid", play.UserId));
            command.Parameters.Add(Db.CreateParameter(command, DbType.DateTime, "@playdate", play.PlayDate));
        }

        public string InsertSql()
        {
            return "insert into plays(track_id,user_id,play_date) values(@trackid,@userid,@playdate)";
        }

        public void ApplyAutoNumber(Play play, int newId)
        {
            play.Id = newId;
        }

        public void ApplyUpdate(Play play, IDbCommand command)
        {
            command.Parameters.Add(Db.CreateParameter(command, DbType.Int32, "@playid", play.Id));
            command.Parameters.Add(Db.CreateParameter(command, DbType.String, "@duration", play.Span.ToString()));
        }

        public string UpdateSql()
        {
            return "update plays set play_duration=@duration where play_id=@playid";
        }

    }
}
