﻿// License: The MIT License (MIT) Copyright (c) 2011..2012 Barend Gehrels

// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;

namespace GrooveSharp
{
    public partial class ConfigurationEditor : UserControl
    {
        public ConfigurationEditor()
        {
            InitializeComponent();

            if (!DesignerProperties.GetIsInDesignMode(this))
            {
                checkBoxAnnounce.IsChecked = SettingManager.UseAnnouncer();
            }
        }

        private void checkBox_Click(object sender, RoutedEventArgs e)
        {
            SettingManager.Reset();
            SettingManager.InsertOrUpdate(checkBoxAnnounce.IsChecked);
        }

        private void buttonSaveAsXml_Click(object sender, RoutedEventArgs e)
        {
            var dialog = new Microsoft.Win32.SaveFileDialog();
            dialog.DefaultExt = ".xml";
            dialog.Filter = "XML files|*.xml";
            dialog.OverwritePrompt = true;
            bool? result = dialog.ShowDialog();
            if (result.HasValue && result.Value)
            {
                Exporter.Export(dialog.FileName);
            }
        }

        private void buttonLoadFromXml_Click(object sender, RoutedEventArgs e)
        {
            var dialog = new Microsoft.Win32.OpenFileDialog();
            dialog.DefaultExt = ".xml";
            dialog.Filter = "XML files|*.xml";
            bool? result = dialog.ShowDialog();
            if (result.HasValue && result.Value)
            {
                AnalyzeAndImport.Import(dialog.FileName);
            }
        }

        public void Refresh()
        {
            theConfigurationFlags.Refresh();
            theConfigurationFolders.Refresh();
        }

        public bool CommitIfNecessary()
        {
            // Commit flags, not relevant for return value...
            theConfigurationFlags.CommitIfNecessary();

            // ... and folders (relevant because rescan necessary)
            return theConfigurationFolders.CommitIfNecessary();
        }

    }
}
